# Agent 执行器

## 什么是 Agent 执行器？

Agent 执行器是 AstrBot 中用于执行 Agent 的组件，Agent 执行器负责了所有关于 AI 的功能。

AstrBot 内置了**强大的** Agent 执行器，用户也可以选择接入第三方的 Agent 执行器服务，例如 Dify、Coze、阿里云百炼应用、DeerFlow 等，或者自己开发 Agent 执行器。

想象一下，你现在已经有 AI 模型提供商，它接收你的单次请求，然后返回响应。你需要一个东西来调用这个 AI 模型提供商来实现多轮对话、工具调用等功能，这就是 Agent 执行器 的作用。

要了解更多，请参阅 [使用 · Agent 执行器](/use/agent-runner)。

## 快捷链接

- [内置 Agent 执行器](/providers/agent-runners/astrbot-agent-runner)
- [Dify](/providers/agent-runners/dify)
- [扣子 Coze](/providers/agent-runners/coze)
- [阿里云百炼应用](/providers/agent-runners/dashscope)
- [DeerFlow](/providers/agent-runners/deerflow)
